# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nodes.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from . import tags_pb2 as tags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bnodes.proto\x12\x02v1\x1a\x1egoogle/protobuf/duration.proto\x1a\roptions.proto\x1a\nspec.proto\x1a\ntags.proto\"`\n\x11NodeCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\"\n\x04node\x18\x02 \x01(\x0b\x32\x08.v1.NodeB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf3\x01\n\x12NodeCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04node\x18\x02 \x01(\x0b\x32\x08.v1.NodeB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\x05token\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xf0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x04 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"N\n\x0eNodeGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xcd\x01\n\x0fNodeGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04node\x18\x02 \x01(\x0b\x32\x08.v1.NodeB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"l\n\x11NodeUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12\"\n\x04node\x18\x03 \x01(\x0b\x32\x08.v1.NodeB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd3\x01\n\x12NodeUpdateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04node\x18\x02 \x01(\x0b\x32\x08.v1.NodeB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"T\n\x11NodeDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xaf\x01\n\x12NodeDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"T\n\x0fNodeListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb8\x01\n\x10NodeListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12#\n\x05nodes\x18\x02 \x03(\x0b\x32\x08.v1.NodeB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\x8f\x01\n\x13NodeTCPProbeRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x1b\n\x07node_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x18\n\x04host\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x18\n\x04port\x18\x04 \x01(\x05\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xeb\x01\n\x14NodeTCPProbeResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\tsucceeded\x18\x02 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05\x65rror\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x04 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x94\x02\n\x04Node\x12&\n\x05relay\x18\x01 \x01(\x0b\x32\t.v1.RelayB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12*\n\x07gateway\x18\x02 \x01(\x0b\x32\x0b.v1.GatewayB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12\x35\n\rproxy_cluster\x18\x03 \x01(\x0b\x32\x10.v1.ProxyClusterB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00:[\xfa\xf8\xb3\x07L\xc2\xf3\xb3\x07G\xa2\xf3\xb3\x07\x1dtf_examples/node_resource.txt\xaa\xf3\xb3\x07 tf_examples/node_data_source.txt\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x42$\n\x04node\x12\x1c\xaa\xf8\xb3\x07\t\xaa\xf8\xb3\x07\x04tags\xaa\xf8\xb3\x07\t\xaa\xf8\xb3\x07\x04name\"\xa8\x04\n\x05Relay\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01\x12<\n\x05state\x18\x03 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x0egateway_filter\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x06\x64\x65vice\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12!\n\x08location\x18\x07 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12 \n\x07version\x18\x08 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12,\n\x04uuid\x18\t \x01(\tB\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\x12t\n\x13maintenance_windows\x18\x0b \x03(\x0b\x32\x19.v1.NodeMaintenanceWindowB<\xf2\xf8\xb3\x07\x37\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07-\xc2\xf4\xb3\x07(\n\x12terraform-provider\x12\x12maintenance_window\x12L\n\x10\x64iscovery_config\x18\x0c \x01(\x0b\x32\x17.v1.NodeDiscoveryConfigB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x84\x05\n\x07Gateway\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01\x12<\n\x05state\x18\x03 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider\x12,\n\x0elisten_address\x18\x04 \x01(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xe0\xf3\xb3\x07\x01\x12*\n\x0c\x62ind_address\x18\x05 \x01(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xe0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01\x12\"\n\x04tags\x18\x06 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x0egateway_filter\x18\x07 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x06\x64\x65vice\x18\x08 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12!\n\x08location\x18\t \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12 \n\x07version\x18\n \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12,\n\x04uuid\x18\x0b \x01(\tB\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\x12t\n\x13maintenance_windows\x18\r \x03(\x0b\x32\x19.v1.NodeMaintenanceWindowB<\xf2\xf8\xb3\x07\x37\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07-\xc2\xf4\xb3\x07(\n\x12terraform-provider\x12\x12maintenance_window\x12L\n\x10\x64iscovery_config\x18\x0e \x01(\x0b\x32\x17.v1.NodeDiscoveryConfigB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xdb\x02\n\x0cProxyCluster\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01\x12 \n\x07\x61\x64\x64ress\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12t\n\x13maintenance_windows\x18\x05 \x03(\x0b\x32\x19.v1.NodeMaintenanceWindowB<\xf2\xf8\xb3\x07\x37\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07-\xc2\xf4\xb3\x07(\n\x12terraform-provider\x12\x12maintenance_window\x12L\n\x10\x64iscovery_config\x18\x06 \x01(\x0b\x32\x17.v1.NodeDiscoveryConfigB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xb6\x01\n\x15NodeMaintenanceWindow\x12!\n\rcron_schedule\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x10require_idleness\x18\x02 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:T\xfa\xf8\xb3\x07O\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x45\xf2\xf3\xb3\x07\x1e\n\x12terraform-provider\x12\x08TypeList\xfa\xf3\xb3\x07\x1dnodeMaintenanceWindowElemType\"\xc3\x01\n\x13NodeDiscoveryConfig\x12\x1b\n\x07\x65nabled\x18\x01 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\x06period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12=\n\x0c\x65nabledTypes\x18\x03 \x03(\x0b\x32\x1b.v1.NodeDiscoveryTypeConfigB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private\"N\n\x17NodeDiscoveryTypeConfig\x12\x18\n\x04type\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private2\x93\x05\n\x05Nodes\x12Z\n\x06\x43reate\x12\x15.v1.NodeCreateRequest\x1a\x16.v1.NodeCreateResponse\"!\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x0e\xaa\xf3\xb3\x07\t/v1/nodes\x12U\n\x03Get\x12\x12.v1.NodeGetRequest\x1a\x13.v1.NodeGetResponse\"%\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/nodes/{id}\x12^\n\x06Update\x12\x15.v1.NodeUpdateRequest\x1a\x16.v1.NodeUpdateResponse\"%\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/nodes/{id}\x12\x61\n\x06\x44\x65lete\x12\x15.v1.NodeDeleteRequest\x1a\x16.v1.NodeDeleteResponse\"(\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/nodes/{id}\x12S\n\x04List\x12\x13.v1.NodeListRequest\x1a\x14.v1.NodeListResponse\" \x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x0e\xaa\xf3\xb3\x07\t/v1/nodes\x12\x89\x01\n\x08TCPProbe\x12\x17.v1.NodeTCPProbeRequest\x1a\x18.v1.NodeTCPProbeResponse\"J\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x18\xaa\xf3\xb3\x07\x13/v1/nodes/tcp-probe\x82\xf9\xb3\x07\x1a\xca\xf3\xb3\x07\x15\xc2\xf4\xb3\x07\x10\n\x04java\x12\x08tcpProbe\x1a\x33\xca\xf9\xb3\x07\t\xc2\xf9\xb3\x07\x04Node\xca\xf9\xb3\x07\x07\xd2\xf9\xb3\x07\x02n-\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\t\xca\xf9\xb3\x07\x04!cliBa\n\x19\x63om.strongdm.api.plumbingB\rNodesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_NODECREATEREQUEST = DESCRIPTOR.message_types_by_name['NodeCreateRequest']
_NODECREATERESPONSE = DESCRIPTOR.message_types_by_name['NodeCreateResponse']
_NODEGETREQUEST = DESCRIPTOR.message_types_by_name['NodeGetRequest']
_NODEGETRESPONSE = DESCRIPTOR.message_types_by_name['NodeGetResponse']
_NODEUPDATEREQUEST = DESCRIPTOR.message_types_by_name['NodeUpdateRequest']
_NODEUPDATERESPONSE = DESCRIPTOR.message_types_by_name['NodeUpdateResponse']
_NODEDELETEREQUEST = DESCRIPTOR.message_types_by_name['NodeDeleteRequest']
_NODEDELETERESPONSE = DESCRIPTOR.message_types_by_name['NodeDeleteResponse']
_NODELISTREQUEST = DESCRIPTOR.message_types_by_name['NodeListRequest']
_NODELISTRESPONSE = DESCRIPTOR.message_types_by_name['NodeListResponse']
_NODETCPPROBEREQUEST = DESCRIPTOR.message_types_by_name['NodeTCPProbeRequest']
_NODETCPPROBERESPONSE = DESCRIPTOR.message_types_by_name['NodeTCPProbeResponse']
_NODE = DESCRIPTOR.message_types_by_name['Node']
_RELAY = DESCRIPTOR.message_types_by_name['Relay']
_GATEWAY = DESCRIPTOR.message_types_by_name['Gateway']
_PROXYCLUSTER = DESCRIPTOR.message_types_by_name['ProxyCluster']
_NODEMAINTENANCEWINDOW = DESCRIPTOR.message_types_by_name['NodeMaintenanceWindow']
_NODEDISCOVERYCONFIG = DESCRIPTOR.message_types_by_name['NodeDiscoveryConfig']
_NODEDISCOVERYTYPECONFIG = DESCRIPTOR.message_types_by_name['NodeDiscoveryTypeConfig']
NodeCreateRequest = _reflection.GeneratedProtocolMessageType('NodeCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODECREATEREQUEST,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeCreateRequest)
  })
_sym_db.RegisterMessage(NodeCreateRequest)

NodeCreateResponse = _reflection.GeneratedProtocolMessageType('NodeCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODECREATERESPONSE,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeCreateResponse)
  })
_sym_db.RegisterMessage(NodeCreateResponse)

NodeGetRequest = _reflection.GeneratedProtocolMessageType('NodeGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODEGETREQUEST,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeGetRequest)
  })
_sym_db.RegisterMessage(NodeGetRequest)

NodeGetResponse = _reflection.GeneratedProtocolMessageType('NodeGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODEGETRESPONSE,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeGetResponse)
  })
_sym_db.RegisterMessage(NodeGetResponse)

NodeUpdateRequest = _reflection.GeneratedProtocolMessageType('NodeUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODEUPDATEREQUEST,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeUpdateRequest)
  })
_sym_db.RegisterMessage(NodeUpdateRequest)

NodeUpdateResponse = _reflection.GeneratedProtocolMessageType('NodeUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODEUPDATERESPONSE,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeUpdateResponse)
  })
_sym_db.RegisterMessage(NodeUpdateResponse)

NodeDeleteRequest = _reflection.GeneratedProtocolMessageType('NodeDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODEDELETEREQUEST,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeDeleteRequest)
  })
_sym_db.RegisterMessage(NodeDeleteRequest)

NodeDeleteResponse = _reflection.GeneratedProtocolMessageType('NodeDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODEDELETERESPONSE,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeDeleteResponse)
  })
_sym_db.RegisterMessage(NodeDeleteResponse)

NodeListRequest = _reflection.GeneratedProtocolMessageType('NodeListRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODELISTREQUEST,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeListRequest)
  })
_sym_db.RegisterMessage(NodeListRequest)

NodeListResponse = _reflection.GeneratedProtocolMessageType('NodeListResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODELISTRESPONSE,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeListResponse)
  })
_sym_db.RegisterMessage(NodeListResponse)

NodeTCPProbeRequest = _reflection.GeneratedProtocolMessageType('NodeTCPProbeRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODETCPPROBEREQUEST,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeTCPProbeRequest)
  })
_sym_db.RegisterMessage(NodeTCPProbeRequest)

NodeTCPProbeResponse = _reflection.GeneratedProtocolMessageType('NodeTCPProbeResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODETCPPROBERESPONSE,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeTCPProbeResponse)
  })
_sym_db.RegisterMessage(NodeTCPProbeResponse)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
  'DESCRIPTOR' : _NODE,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.Node)
  })
_sym_db.RegisterMessage(Node)

Relay = _reflection.GeneratedProtocolMessageType('Relay', (_message.Message,), {
  'DESCRIPTOR' : _RELAY,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.Relay)
  })
_sym_db.RegisterMessage(Relay)

Gateway = _reflection.GeneratedProtocolMessageType('Gateway', (_message.Message,), {
  'DESCRIPTOR' : _GATEWAY,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.Gateway)
  })
_sym_db.RegisterMessage(Gateway)

ProxyCluster = _reflection.GeneratedProtocolMessageType('ProxyCluster', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTER,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyCluster)
  })
_sym_db.RegisterMessage(ProxyCluster)

NodeMaintenanceWindow = _reflection.GeneratedProtocolMessageType('NodeMaintenanceWindow', (_message.Message,), {
  'DESCRIPTOR' : _NODEMAINTENANCEWINDOW,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeMaintenanceWindow)
  })
_sym_db.RegisterMessage(NodeMaintenanceWindow)

NodeDiscoveryConfig = _reflection.GeneratedProtocolMessageType('NodeDiscoveryConfig', (_message.Message,), {
  'DESCRIPTOR' : _NODEDISCOVERYCONFIG,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeDiscoveryConfig)
  })
_sym_db.RegisterMessage(NodeDiscoveryConfig)

NodeDiscoveryTypeConfig = _reflection.GeneratedProtocolMessageType('NodeDiscoveryTypeConfig', (_message.Message,), {
  'DESCRIPTOR' : _NODEDISCOVERYTYPECONFIG,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeDiscoveryTypeConfig)
  })
_sym_db.RegisterMessage(NodeDiscoveryTypeConfig)

_NODES = DESCRIPTOR.services_by_name['Nodes']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\rNodesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _NODECREATEREQUEST.fields_by_name['node']._options = None
  _NODECREATEREQUEST.fields_by_name['node']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODECREATERESPONSE.fields_by_name['meta']._options = None
  _NODECREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODECREATERESPONSE.fields_by_name['node']._options = None
  _NODECREATERESPONSE.fields_by_name['node']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODECREATERESPONSE.fields_by_name['token']._options = None
  _NODECREATERESPONSE.fields_by_name['token']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\360\363\263\007\001'
  _NODECREATERESPONSE.fields_by_name['rate_limit']._options = None
  _NODECREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _NODECREATERESPONSE._options = None
  _NODECREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _NODEGETREQUEST.fields_by_name['id']._options = None
  _NODEGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEGETRESPONSE.fields_by_name['meta']._options = None
  _NODEGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEGETRESPONSE.fields_by_name['node']._options = None
  _NODEGETRESPONSE.fields_by_name['node']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEGETRESPONSE.fields_by_name['rate_limit']._options = None
  _NODEGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _NODEGETRESPONSE._options = None
  _NODEGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _NODEUPDATEREQUEST.fields_by_name['node']._options = None
  _NODEUPDATEREQUEST.fields_by_name['node']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEUPDATERESPONSE.fields_by_name['meta']._options = None
  _NODEUPDATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEUPDATERESPONSE.fields_by_name['node']._options = None
  _NODEUPDATERESPONSE.fields_by_name['node']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _NODEUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _NODEUPDATERESPONSE._options = None
  _NODEUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _NODEDELETEREQUEST.fields_by_name['id']._options = None
  _NODEDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEDELETERESPONSE.fields_by_name['meta']._options = None
  _NODEDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _NODEDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _NODEDELETERESPONSE._options = None
  _NODEDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _NODELISTREQUEST.fields_by_name['filter']._options = None
  _NODELISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODELISTRESPONSE.fields_by_name['nodes']._options = None
  _NODELISTRESPONSE.fields_by_name['nodes']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _NODELISTRESPONSE.fields_by_name['rate_limit']._options = None
  _NODELISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _NODETCPPROBEREQUEST.fields_by_name['node_id']._options = None
  _NODETCPPROBEREQUEST.fields_by_name['node_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODETCPPROBEREQUEST.fields_by_name['host']._options = None
  _NODETCPPROBEREQUEST.fields_by_name['host']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODETCPPROBEREQUEST.fields_by_name['port']._options = None
  _NODETCPPROBEREQUEST.fields_by_name['port']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODETCPPROBERESPONSE.fields_by_name['meta']._options = None
  _NODETCPPROBERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODETCPPROBERESPONSE.fields_by_name['succeeded']._options = None
  _NODETCPPROBERESPONSE.fields_by_name['succeeded']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODETCPPROBERESPONSE.fields_by_name['error']._options = None
  _NODETCPPROBERESPONSE.fields_by_name['error']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODETCPPROBERESPONSE.fields_by_name['rate_limit']._options = None
  _NODETCPPROBERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _NODETCPPROBERESPONSE._options = None
  _NODETCPPROBERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _NODE.oneofs_by_name['node']._options = None
  _NODE.oneofs_by_name['node']._serialized_options = b'\252\370\263\007\t\252\370\263\007\004tags\252\370\263\007\t\252\370\263\007\004name'
  _NODE.fields_by_name['relay']._options = None
  _NODE.fields_by_name['relay']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODE.fields_by_name['gateway']._options = None
  _NODE.fields_by_name['gateway']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODE.fields_by_name['proxy_cluster']._options = None
  _NODE.fields_by_name['proxy_cluster']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODE._options = None
  _NODE._serialized_options = b'\372\370\263\007L\302\363\263\007G\242\363\263\007\035tf_examples/node_resource.txt\252\363\263\007 tf_examples/node_data_source.txt\372\370\263\007\005\250\363\263\007\001'
  _RELAY.fields_by_name['id']._options = None
  _RELAY.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RELAY.fields_by_name['name']._options = None
  _RELAY.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\320\364\263\007\001'
  _RELAY.fields_by_name['state']._options = None
  _RELAY.fields_by_name['state']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider'
  _RELAY.fields_by_name['tags']._options = None
  _RELAY.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RELAY.fields_by_name['gateway_filter']._options = None
  _RELAY.fields_by_name['gateway_filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RELAY.fields_by_name['device']._options = None
  _RELAY.fields_by_name['device']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _RELAY.fields_by_name['location']._options = None
  _RELAY.fields_by_name['location']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _RELAY.fields_by_name['version']._options = None
  _RELAY.fields_by_name['version']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _RELAY.fields_by_name['uuid']._options = None
  _RELAY.fields_by_name['uuid']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\ngo_private'
  _RELAY.fields_by_name['maintenance_windows']._options = None
  _RELAY.fields_by_name['maintenance_windows']._serialized_options = b'\362\370\263\0077\260\363\263\007\001\312\363\263\007-\302\364\263\007(\n\022terraform-provider\022\022maintenance_window'
  _RELAY.fields_by_name['discovery_config']._options = None
  _RELAY.fields_by_name['discovery_config']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _RELAY._options = None
  _RELAY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _GATEWAY.fields_by_name['id']._options = None
  _GATEWAY.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GATEWAY.fields_by_name['name']._options = None
  _GATEWAY.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\320\364\263\007\001'
  _GATEWAY.fields_by_name['state']._options = None
  _GATEWAY.fields_by_name['state']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider'
  _GATEWAY.fields_by_name['listen_address']._options = None
  _GATEWAY.fields_by_name['listen_address']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\300\363\263\007\001\340\363\263\007\001'
  _GATEWAY.fields_by_name['bind_address']._options = None
  _GATEWAY.fields_by_name['bind_address']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\340\363\263\007\001\320\364\263\007\001'
  _GATEWAY.fields_by_name['tags']._options = None
  _GATEWAY.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GATEWAY.fields_by_name['gateway_filter']._options = None
  _GATEWAY.fields_by_name['gateway_filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GATEWAY.fields_by_name['device']._options = None
  _GATEWAY.fields_by_name['device']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _GATEWAY.fields_by_name['location']._options = None
  _GATEWAY.fields_by_name['location']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _GATEWAY.fields_by_name['version']._options = None
  _GATEWAY.fields_by_name['version']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _GATEWAY.fields_by_name['uuid']._options = None
  _GATEWAY.fields_by_name['uuid']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\ngo_private'
  _GATEWAY.fields_by_name['maintenance_windows']._options = None
  _GATEWAY.fields_by_name['maintenance_windows']._serialized_options = b'\362\370\263\0077\260\363\263\007\001\312\363\263\007-\302\364\263\007(\n\022terraform-provider\022\022maintenance_window'
  _GATEWAY.fields_by_name['discovery_config']._options = None
  _GATEWAY.fields_by_name['discovery_config']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _GATEWAY._options = None
  _GATEWAY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PROXYCLUSTER.fields_by_name['id']._options = None
  _PROXYCLUSTER.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTER.fields_by_name['name']._options = None
  _PROXYCLUSTER.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\320\364\263\007\001'
  _PROXYCLUSTER.fields_by_name['address']._options = None
  _PROXYCLUSTER.fields_by_name['address']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _PROXYCLUSTER.fields_by_name['tags']._options = None
  _PROXYCLUSTER.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTER.fields_by_name['maintenance_windows']._options = None
  _PROXYCLUSTER.fields_by_name['maintenance_windows']._serialized_options = b'\362\370\263\0077\260\363\263\007\001\312\363\263\007-\302\364\263\007(\n\022terraform-provider\022\022maintenance_window'
  _PROXYCLUSTER.fields_by_name['discovery_config']._options = None
  _PROXYCLUSTER.fields_by_name['discovery_config']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _PROXYCLUSTER._options = None
  _PROXYCLUSTER._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _NODEMAINTENANCEWINDOW.fields_by_name['cron_schedule']._options = None
  _NODEMAINTENANCEWINDOW.fields_by_name['cron_schedule']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEMAINTENANCEWINDOW.fields_by_name['require_idleness']._options = None
  _NODEMAINTENANCEWINDOW.fields_by_name['require_idleness']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEMAINTENANCEWINDOW._options = None
  _NODEMAINTENANCEWINDOW._serialized_options = b'\372\370\263\007O\250\363\263\007\001\312\363\263\007E\362\363\263\007\036\n\022terraform-provider\022\010TypeList\372\363\263\007\035nodeMaintenanceWindowElemType'
  _NODEDISCOVERYCONFIG.fields_by_name['enabled']._options = None
  _NODEDISCOVERYCONFIG.fields_by_name['enabled']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEDISCOVERYCONFIG.fields_by_name['period']._options = None
  _NODEDISCOVERYCONFIG.fields_by_name['period']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEDISCOVERYCONFIG.fields_by_name['enabledTypes']._options = None
  _NODEDISCOVERYCONFIG.fields_by_name['enabledTypes']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEDISCOVERYCONFIG._options = None
  _NODEDISCOVERYCONFIG._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _NODEDISCOVERYTYPECONFIG.fields_by_name['type']._options = None
  _NODEDISCOVERYTYPECONFIG.fields_by_name['type']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEDISCOVERYTYPECONFIG._options = None
  _NODEDISCOVERYTYPECONFIG._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _NODES._options = None
  _NODES._serialized_options = b'\312\371\263\007\t\302\371\263\007\004Node\312\371\263\007\007\322\371\263\007\002n-\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\t\312\371\263\007\004!cli'
  _NODES.methods_by_name['Create']._options = None
  _NODES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\016\252\363\263\007\t/v1/nodes'
  _NODES.methods_by_name['Get']._options = None
  _NODES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\023\252\363\263\007\016/v1/nodes/{id}'
  _NODES.methods_by_name['Update']._options = None
  _NODES.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\023\252\363\263\007\016/v1/nodes/{id}'
  _NODES.methods_by_name['Delete']._options = None
  _NODES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\023\252\363\263\007\016/v1/nodes/{id}'
  _NODES.methods_by_name['List']._options = None
  _NODES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\016\252\363\263\007\t/v1/nodes'
  _NODES.methods_by_name['TCPProbe']._options = None
  _NODES.methods_by_name['TCPProbe']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\030\252\363\263\007\023/v1/nodes/tcp-probe\202\371\263\007\032\312\363\263\007\025\302\364\263\007\020\n\004java\022\010tcpProbe'
  _NODECREATEREQUEST._serialized_start=90
  _NODECREATEREQUEST._serialized_end=186
  _NODECREATERESPONSE._serialized_start=189
  _NODECREATERESPONSE._serialized_end=432
  _NODEGETREQUEST._serialized_start=434
  _NODEGETREQUEST._serialized_end=512
  _NODEGETRESPONSE._serialized_start=515
  _NODEGETRESPONSE._serialized_end=720
  _NODEUPDATEREQUEST._serialized_start=722
  _NODEUPDATEREQUEST._serialized_end=830
  _NODEUPDATERESPONSE._serialized_start=833
  _NODEUPDATERESPONSE._serialized_end=1044
  _NODEDELETEREQUEST._serialized_start=1046
  _NODEDELETEREQUEST._serialized_end=1130
  _NODEDELETERESPONSE._serialized_start=1133
  _NODEDELETERESPONSE._serialized_end=1308
  _NODELISTREQUEST._serialized_start=1310
  _NODELISTREQUEST._serialized_end=1394
  _NODELISTRESPONSE._serialized_start=1397
  _NODELISTRESPONSE._serialized_end=1581
  _NODETCPPROBEREQUEST._serialized_start=1584
  _NODETCPPROBEREQUEST._serialized_end=1727
  _NODETCPPROBERESPONSE._serialized_start=1730
  _NODETCPPROBERESPONSE._serialized_end=1965
  _NODE._serialized_start=1968
  _NODE._serialized_end=2244
  _RELAY._serialized_start=2247
  _RELAY._serialized_end=2799
  _GATEWAY._serialized_start=2802
  _GATEWAY._serialized_end=3446
  _PROXYCLUSTER._serialized_start=3449
  _PROXYCLUSTER._serialized_end=3796
  _NODEMAINTENANCEWINDOW._serialized_start=3799
  _NODEMAINTENANCEWINDOW._serialized_end=3981
  _NODEDISCOVERYCONFIG._serialized_start=3984
  _NODEDISCOVERYCONFIG._serialized_end=4179
  _NODEDISCOVERYTYPECONFIG._serialized_start=4181
  _NODEDISCOVERYTYPECONFIG._serialized_end=4259
  _NODES._serialized_start=4262
  _NODES._serialized_end=4921
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: account_attachments.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61\x63\x63ount_attachments.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"\x9b\x01\n\x1e\x41\x63\x63ountAttachmentCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12=\n\x12\x61\x63\x63ount_attachment\x18\x02 \x01(\x0b\x32\x15.v1.AccountAttachmentB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x11\xfa\xf8\xb3\x07\x0c\xba\xf3\xb3\x07\x07options\"\xfb\x01\n\x1f\x41\x63\x63ountAttachmentCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12=\n\x12\x61\x63\x63ount_attachment\x18\x02 \x01(\x0b\x32\x15.v1.AccountAttachmentB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"[\n\x1b\x41\x63\x63ountAttachmentGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf5\x01\n\x1c\x41\x63\x63ountAttachmentGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12=\n\x12\x61\x63\x63ount_attachment\x18\x02 \x01(\x0b\x32\x15.v1.AccountAttachmentB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"a\n\x1e\x41\x63\x63ountAttachmentDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xbc\x01\n\x1f\x41\x63\x63ountAttachmentDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"a\n\x1c\x41\x63\x63ountAttachmentListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xe0\x01\n\x1d\x41\x63\x63ountAttachmentListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12>\n\x13\x61\x63\x63ount_attachments\x18\x02 \x03(\x0b\x32\x15.v1.AccountAttachmentB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\xe6\x01\n\x11\x41\x63\x63ountAttachment\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12#\n\naccount_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12 \n\x07role_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01:r\xfa\xf8\xb3\x07m\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07\x63\xa2\xf3\xb3\x07+tf_examples/account_attachment_resource.txt\xaa\xf3\xb3\x07.tf_examples/account_attachment_data_source.txt2\xcb\x04\n\x12\x41\x63\x63ountAttachments\x12\x82\x01\n\x06\x43reate\x12\".v1.AccountAttachmentCreateRequest\x1a#.v1.AccountAttachmentCreateResponse\"/\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1c\xaa\xf3\xb3\x07\x17/v1/account-attachments\x12}\n\x03Get\x12\x1f.v1.AccountAttachmentGetRequest\x1a .v1.AccountAttachmentGetResponse\"3\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07!\xaa\xf3\xb3\x07\x1c/v1/account-attachments/{id}\x12\x89\x01\n\x06\x44\x65lete\x12\".v1.AccountAttachmentDeleteRequest\x1a#.v1.AccountAttachmentDeleteResponse\"6\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07!\xaa\xf3\xb3\x07\x1c/v1/account-attachments/{id}\x12{\n\x04List\x12 .v1.AccountAttachmentListRequest\x1a!.v1.AccountAttachmentListResponse\".\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1c\xaa\xf3\xb3\x07\x17/v1/account-attachments\x1a(\xca\xf9\xb3\x07\x16\xc2\xf9\xb3\x07\x11\x41\x63\x63ountAttachment\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03\x61\x61-Bn\n\x19\x63om.strongdm.api.plumbingB\x1a\x41\x63\x63ountAttachmentsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_ACCOUNTATTACHMENTCREATEREQUEST = DESCRIPTOR.message_types_by_name['AccountAttachmentCreateRequest']
_ACCOUNTATTACHMENTCREATERESPONSE = DESCRIPTOR.message_types_by_name['AccountAttachmentCreateResponse']
_ACCOUNTATTACHMENTGETREQUEST = DESCRIPTOR.message_types_by_name['AccountAttachmentGetRequest']
_ACCOUNTATTACHMENTGETRESPONSE = DESCRIPTOR.message_types_by_name['AccountAttachmentGetResponse']
_ACCOUNTATTACHMENTDELETEREQUEST = DESCRIPTOR.message_types_by_name['AccountAttachmentDeleteRequest']
_ACCOUNTATTACHMENTDELETERESPONSE = DESCRIPTOR.message_types_by_name['AccountAttachmentDeleteResponse']
_ACCOUNTATTACHMENTLISTREQUEST = DESCRIPTOR.message_types_by_name['AccountAttachmentListRequest']
_ACCOUNTATTACHMENTLISTRESPONSE = DESCRIPTOR.message_types_by_name['AccountAttachmentListResponse']
_ACCOUNTATTACHMENT = DESCRIPTOR.message_types_by_name['AccountAttachment']
AccountAttachmentCreateRequest = _reflection.GeneratedProtocolMessageType('AccountAttachmentCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTATTACHMENTCREATEREQUEST,
  '__module__' : 'account_attachments_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountAttachmentCreateRequest)
  })
_sym_db.RegisterMessage(AccountAttachmentCreateRequest)

AccountAttachmentCreateResponse = _reflection.GeneratedProtocolMessageType('AccountAttachmentCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTATTACHMENTCREATERESPONSE,
  '__module__' : 'account_attachments_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountAttachmentCreateResponse)
  })
_sym_db.RegisterMessage(AccountAttachmentCreateResponse)

AccountAttachmentGetRequest = _reflection.GeneratedProtocolMessageType('AccountAttachmentGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTATTACHMENTGETREQUEST,
  '__module__' : 'account_attachments_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountAttachmentGetRequest)
  })
_sym_db.RegisterMessage(AccountAttachmentGetRequest)

AccountAttachmentGetResponse = _reflection.GeneratedProtocolMessageType('AccountAttachmentGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTATTACHMENTGETRESPONSE,
  '__module__' : 'account_attachments_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountAttachmentGetResponse)
  })
_sym_db.RegisterMessage(AccountAttachmentGetResponse)

AccountAttachmentDeleteRequest = _reflection.GeneratedProtocolMessageType('AccountAttachmentDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTATTACHMENTDELETEREQUEST,
  '__module__' : 'account_attachments_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountAttachmentDeleteRequest)
  })
_sym_db.RegisterMessage(AccountAttachmentDeleteRequest)

AccountAttachmentDeleteResponse = _reflection.GeneratedProtocolMessageType('AccountAttachmentDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTATTACHMENTDELETERESPONSE,
  '__module__' : 'account_attachments_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountAttachmentDeleteResponse)
  })
_sym_db.RegisterMessage(AccountAttachmentDeleteResponse)

AccountAttachmentListRequest = _reflection.GeneratedProtocolMessageType('AccountAttachmentListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTATTACHMENTLISTREQUEST,
  '__module__' : 'account_attachments_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountAttachmentListRequest)
  })
_sym_db.RegisterMessage(AccountAttachmentListRequest)

AccountAttachmentListResponse = _reflection.GeneratedProtocolMessageType('AccountAttachmentListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTATTACHMENTLISTRESPONSE,
  '__module__' : 'account_attachments_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountAttachmentListResponse)
  })
_sym_db.RegisterMessage(AccountAttachmentListResponse)

AccountAttachment = _reflection.GeneratedProtocolMessageType('AccountAttachment', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTATTACHMENT,
  '__module__' : 'account_attachments_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountAttachment)
  })
_sym_db.RegisterMessage(AccountAttachment)

_ACCOUNTATTACHMENTS = DESCRIPTOR.services_by_name['AccountAttachments']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\032AccountAttachmentsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _ACCOUNTATTACHMENTCREATEREQUEST.fields_by_name['account_attachment']._options = None
  _ACCOUNTATTACHMENTCREATEREQUEST.fields_by_name['account_attachment']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTATTACHMENTCREATEREQUEST._options = None
  _ACCOUNTATTACHMENTCREATEREQUEST._serialized_options = b'\372\370\263\007\014\272\363\263\007\007options'
  _ACCOUNTATTACHMENTCREATERESPONSE.fields_by_name['meta']._options = None
  _ACCOUNTATTACHMENTCREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTATTACHMENTCREATERESPONSE.fields_by_name['account_attachment']._options = None
  _ACCOUNTATTACHMENTCREATERESPONSE.fields_by_name['account_attachment']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTATTACHMENTCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTATTACHMENTCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ACCOUNTATTACHMENTCREATERESPONSE._options = None
  _ACCOUNTATTACHMENTCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ACCOUNTATTACHMENTGETREQUEST.fields_by_name['id']._options = None
  _ACCOUNTATTACHMENTGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTATTACHMENTGETRESPONSE.fields_by_name['meta']._options = None
  _ACCOUNTATTACHMENTGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTATTACHMENTGETRESPONSE.fields_by_name['account_attachment']._options = None
  _ACCOUNTATTACHMENTGETRESPONSE.fields_by_name['account_attachment']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTATTACHMENTGETRESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTATTACHMENTGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ACCOUNTATTACHMENTGETRESPONSE._options = None
  _ACCOUNTATTACHMENTGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ACCOUNTATTACHMENTDELETEREQUEST.fields_by_name['id']._options = None
  _ACCOUNTATTACHMENTDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTATTACHMENTDELETERESPONSE.fields_by_name['meta']._options = None
  _ACCOUNTATTACHMENTDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTATTACHMENTDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTATTACHMENTDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ACCOUNTATTACHMENTDELETERESPONSE._options = None
  _ACCOUNTATTACHMENTDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ACCOUNTATTACHMENTLISTREQUEST.fields_by_name['filter']._options = None
  _ACCOUNTATTACHMENTLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTATTACHMENTLISTRESPONSE.fields_by_name['account_attachments']._options = None
  _ACCOUNTATTACHMENTLISTRESPONSE.fields_by_name['account_attachments']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ACCOUNTATTACHMENTLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTATTACHMENTLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ACCOUNTATTACHMENT.fields_by_name['id']._options = None
  _ACCOUNTATTACHMENT.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTATTACHMENT.fields_by_name['account_id']._options = None
  _ACCOUNTATTACHMENT.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACCOUNTATTACHMENT.fields_by_name['role_id']._options = None
  _ACCOUNTATTACHMENT.fields_by_name['role_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACCOUNTATTACHMENT._options = None
  _ACCOUNTATTACHMENT._serialized_options = b'\372\370\263\007m\250\363\263\007\001\302\363\263\007c\242\363\263\007+tf_examples/account_attachment_resource.txt\252\363\263\007.tf_examples/account_attachment_data_source.txt'
  _ACCOUNTATTACHMENTS._options = None
  _ACCOUNTATTACHMENTS._serialized_options = b'\312\371\263\007\026\302\371\263\007\021AccountAttachment\312\371\263\007\010\322\371\263\007\003aa-'
  _ACCOUNTATTACHMENTS.methods_by_name['Create']._options = None
  _ACCOUNTATTACHMENTS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\034\252\363\263\007\027/v1/account-attachments'
  _ACCOUNTATTACHMENTS.methods_by_name['Get']._options = None
  _ACCOUNTATTACHMENTS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007!\252\363\263\007\034/v1/account-attachments/{id}'
  _ACCOUNTATTACHMENTS.methods_by_name['Delete']._options = None
  _ACCOUNTATTACHMENTS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007!\252\363\263\007\034/v1/account-attachments/{id}'
  _ACCOUNTATTACHMENTS.methods_by_name['List']._options = None
  _ACCOUNTATTACHMENTS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\034\252\363\263\007\027/v1/account-attachments'
  _ACCOUNTATTACHMENTCREATEREQUEST._serialized_start=61
  _ACCOUNTATTACHMENTCREATEREQUEST._serialized_end=216
  _ACCOUNTATTACHMENTCREATERESPONSE._serialized_start=219
  _ACCOUNTATTACHMENTCREATERESPONSE._serialized_end=470
  _ACCOUNTATTACHMENTGETREQUEST._serialized_start=472
  _ACCOUNTATTACHMENTGETREQUEST._serialized_end=563
  _ACCOUNTATTACHMENTGETRESPONSE._serialized_start=566
  _ACCOUNTATTACHMENTGETRESPONSE._serialized_end=811
  _ACCOUNTATTACHMENTDELETEREQUEST._serialized_start=813
  _ACCOUNTATTACHMENTDELETEREQUEST._serialized_end=910
  _ACCOUNTATTACHMENTDELETERESPONSE._serialized_start=913
  _ACCOUNTATTACHMENTDELETERESPONSE._serialized_end=1101
  _ACCOUNTATTACHMENTLISTREQUEST._serialized_start=1103
  _ACCOUNTATTACHMENTLISTREQUEST._serialized_end=1200
  _ACCOUNTATTACHMENTLISTRESPONSE._serialized_start=1203
  _ACCOUNTATTACHMENTLISTRESPONSE._serialized_end=1427
  _ACCOUNTATTACHMENT._serialized_start=1430
  _ACCOUNTATTACHMENT._serialized_end=1660
  _ACCOUNTATTACHMENTS._serialized_start=1663
  _ACCOUNTATTACHMENTS._serialized_end=2250
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: remote_identity_groups.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cremote_identity_groups.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"]\n\x1dRemoteIdentityGroupGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xfc\x01\n\x1eRemoteIdentityGroupGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x42\n\x15remote_identity_group\x18\x02 \x01(\x0b\x32\x17.v1.RemoteIdentityGroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"c\n\x1eRemoteIdentityGroupListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xe7\x01\n\x1fRemoteIdentityGroupListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x43\n\x16remote_identity_groups\x18\x02 \x03(\x0b\x32\x17.v1.RemoteIdentityGroupB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\x93\x01\n\x13RemoteIdentityGroup\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01:E\xfa\xf8\xb3\x07@\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07\x36\xaa\xf3\xb3\x07\x31tf_examples/remote_identity_group_data_source.txt2\xd1\x02\n\x14RemoteIdentityGroups\x12\x84\x01\n\x03Get\x12!.v1.RemoteIdentityGroupGetRequest\x1a\".v1.RemoteIdentityGroupGetResponse\"6\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07$\xaa\xf3\xb3\x07\x1f/v1/remote-identity-groups/{id}\x12\x82\x01\n\x04List\x12\".v1.RemoteIdentityGroupListRequest\x1a#.v1.RemoteIdentityGroupListResponse\"1\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1f\xaa\xf3\xb3\x07\x1a/v1/remote-identity-groups\x1a-\x88\x02\x01\xca\xf9\xb3\x07\x18\xc2\xf9\xb3\x07\x13RemoteIdentityGroup\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03ig-Bp\n\x19\x63om.strongdm.api.plumbingB\x1cRemoteIdentityGroupsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_REMOTEIDENTITYGROUPGETREQUEST = DESCRIPTOR.message_types_by_name['RemoteIdentityGroupGetRequest']
_REMOTEIDENTITYGROUPGETRESPONSE = DESCRIPTOR.message_types_by_name['RemoteIdentityGroupGetResponse']
_REMOTEIDENTITYGROUPLISTREQUEST = DESCRIPTOR.message_types_by_name['RemoteIdentityGroupListRequest']
_REMOTEIDENTITYGROUPLISTRESPONSE = DESCRIPTOR.message_types_by_name['RemoteIdentityGroupListResponse']
_REMOTEIDENTITYGROUP = DESCRIPTOR.message_types_by_name['RemoteIdentityGroup']
RemoteIdentityGroupGetRequest = _reflection.GeneratedProtocolMessageType('RemoteIdentityGroupGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYGROUPGETREQUEST,
  '__module__' : 'remote_identity_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityGroupGetRequest)
  })
_sym_db.RegisterMessage(RemoteIdentityGroupGetRequest)

RemoteIdentityGroupGetResponse = _reflection.GeneratedProtocolMessageType('RemoteIdentityGroupGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYGROUPGETRESPONSE,
  '__module__' : 'remote_identity_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityGroupGetResponse)
  })
_sym_db.RegisterMessage(RemoteIdentityGroupGetResponse)

RemoteIdentityGroupListRequest = _reflection.GeneratedProtocolMessageType('RemoteIdentityGroupListRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYGROUPLISTREQUEST,
  '__module__' : 'remote_identity_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityGroupListRequest)
  })
_sym_db.RegisterMessage(RemoteIdentityGroupListRequest)

RemoteIdentityGroupListResponse = _reflection.GeneratedProtocolMessageType('RemoteIdentityGroupListResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYGROUPLISTRESPONSE,
  '__module__' : 'remote_identity_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityGroupListResponse)
  })
_sym_db.RegisterMessage(RemoteIdentityGroupListResponse)

RemoteIdentityGroup = _reflection.GeneratedProtocolMessageType('RemoteIdentityGroup', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYGROUP,
  '__module__' : 'remote_identity_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityGroup)
  })
_sym_db.RegisterMessage(RemoteIdentityGroup)

_REMOTEIDENTITYGROUPS = DESCRIPTOR.services_by_name['RemoteIdentityGroups']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\034RemoteIdentityGroupsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _REMOTEIDENTITYGROUPGETREQUEST.fields_by_name['id']._options = None
  _REMOTEIDENTITYGROUPGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYGROUPGETRESPONSE.fields_by_name['meta']._options = None
  _REMOTEIDENTITYGROUPGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYGROUPGETRESPONSE.fields_by_name['remote_identity_group']._options = None
  _REMOTEIDENTITYGROUPGETRESPONSE.fields_by_name['remote_identity_group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYGROUPGETRESPONSE.fields_by_name['rate_limit']._options = None
  _REMOTEIDENTITYGROUPGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _REMOTEIDENTITYGROUPGETRESPONSE._options = None
  _REMOTEIDENTITYGROUPGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _REMOTEIDENTITYGROUPLISTREQUEST.fields_by_name['filter']._options = None
  _REMOTEIDENTITYGROUPLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYGROUPLISTRESPONSE.fields_by_name['remote_identity_groups']._options = None
  _REMOTEIDENTITYGROUPLISTRESPONSE.fields_by_name['remote_identity_groups']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _REMOTEIDENTITYGROUPLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _REMOTEIDENTITYGROUPLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _REMOTEIDENTITYGROUP.fields_by_name['id']._options = None
  _REMOTEIDENTITYGROUP.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYGROUP.fields_by_name['name']._options = None
  _REMOTEIDENTITYGROUP.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _REMOTEIDENTITYGROUP._options = None
  _REMOTEIDENTITYGROUP._serialized_options = b'\372\370\263\007@\250\363\263\007\001\302\363\263\0076\252\363\263\0071tf_examples/remote_identity_group_data_source.txt'
  _REMOTEIDENTITYGROUPS._options = None
  _REMOTEIDENTITYGROUPS._serialized_options = b'\210\002\001\312\371\263\007\030\302\371\263\007\023RemoteIdentityGroup\312\371\263\007\010\322\371\263\007\003ig-'
  _REMOTEIDENTITYGROUPS.methods_by_name['Get']._options = None
  _REMOTEIDENTITYGROUPS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007$\252\363\263\007\037/v1/remote-identity-groups/{id}'
  _REMOTEIDENTITYGROUPS.methods_by_name['List']._options = None
  _REMOTEIDENTITYGROUPS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\037\252\363\263\007\032/v1/remote-identity-groups'
  _REMOTEIDENTITYGROUPGETREQUEST._serialized_start=63
  _REMOTEIDENTITYGROUPGETREQUEST._serialized_end=156
  _REMOTEIDENTITYGROUPGETRESPONSE._serialized_start=159
  _REMOTEIDENTITYGROUPGETRESPONSE._serialized_end=411
  _REMOTEIDENTITYGROUPLISTREQUEST._serialized_start=413
  _REMOTEIDENTITYGROUPLISTREQUEST._serialized_end=512
  _REMOTEIDENTITYGROUPLISTRESPONSE._serialized_start=515
  _REMOTEIDENTITYGROUPLISTRESPONSE._serialized_end=746
  _REMOTEIDENTITYGROUP._serialized_start=749
  _REMOTEIDENTITYGROUP._serialized_end=896
  _REMOTEIDENTITYGROUPS._serialized_start=899
  _REMOTEIDENTITYGROUPS._serialized_end=1236
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: activities.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x61\x63tivities.proto\x12\x02v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\roptions.proto\x1a\nspec.proto\"|\n\x12\x41\x63tivityGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\x81\x02\n\x13\x41\x63tivityGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12*\n\x08\x61\x63tivity\x18\x02 \x01(\x0b\x32\x0c.v1.ActivityB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:2\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x82\x01\n\x13\x41\x63tivityListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xef\x01\n\x14\x41\x63tivityListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12,\n\nactivities\x18\x02 \x03(\x0b\x32\x0c.v1.ActivityB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\x88\x03\n\x08\x41\x63tivity\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x18\n\x04verb\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12<\n\x0c\x63ompleted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x30\n\x08\x65ntities\x18\x05 \x03(\x0b\x32\x12.v1.ActivityEntityB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x37\n\nip_address\x18\x06 \x01(\tB#\xf2\xf8\xb3\x07\x1e\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x14\xc2\xf4\xb3\x07\x0f\n\x02go\x12\tIPAddress\x12,\n\x05\x61\x63tor\x18\x07 \x01(\x0b\x32\x11.v1.ActivityActorB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\nuser_agent\x18\x08 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xcc\x01\n\x0e\x41\x63tivityEntity\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x18\n\x04type\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x18\n\x04name\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05\x65mail\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x0b\x65xternal_id\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xdf\x01\n\rActivityActor\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05\x65mail\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\nfirst_name\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\tlast_name\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12(\n\x14\x61\x63tivity_external_id\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider2\xa5\x02\n\nActivities\x12\x62\n\x03Get\x12\x16.v1.ActivityGetRequest\x1a\x17.v1.ActivityGetResponse\"*\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x18\xaa\xf3\xb3\x07\x13/v1/activities/{id}\x12`\n\x04List\x12\x17.v1.ActivityListRequest\x1a\x18.v1.ActivityListResponse\"%\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/activities\x1aQ\xca\xf9\xb3\x07\r\xc2\xf9\xb3\x07\x08\x41\x63tivity\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03\x61t-\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerB\x8e\x01\n\x19\x63om.strongdm.api.plumbingB\x12\x41\x63tivitiesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_ACTIVITYGETREQUEST = DESCRIPTOR.message_types_by_name['ActivityGetRequest']
_ACTIVITYGETRESPONSE = DESCRIPTOR.message_types_by_name['ActivityGetResponse']
_ACTIVITYLISTREQUEST = DESCRIPTOR.message_types_by_name['ActivityListRequest']
_ACTIVITYLISTRESPONSE = DESCRIPTOR.message_types_by_name['ActivityListResponse']
_ACTIVITY = DESCRIPTOR.message_types_by_name['Activity']
_ACTIVITYENTITY = DESCRIPTOR.message_types_by_name['ActivityEntity']
_ACTIVITYACTOR = DESCRIPTOR.message_types_by_name['ActivityActor']
ActivityGetRequest = _reflection.GeneratedProtocolMessageType('ActivityGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYGETREQUEST,
  '__module__' : 'activities_pb2'
  # @@protoc_insertion_point(class_scope:v1.ActivityGetRequest)
  })
_sym_db.RegisterMessage(ActivityGetRequest)

ActivityGetResponse = _reflection.GeneratedProtocolMessageType('ActivityGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYGETRESPONSE,
  '__module__' : 'activities_pb2'
  # @@protoc_insertion_point(class_scope:v1.ActivityGetResponse)
  })
_sym_db.RegisterMessage(ActivityGetResponse)

ActivityListRequest = _reflection.GeneratedProtocolMessageType('ActivityListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYLISTREQUEST,
  '__module__' : 'activities_pb2'
  # @@protoc_insertion_point(class_scope:v1.ActivityListRequest)
  })
_sym_db.RegisterMessage(ActivityListRequest)

ActivityListResponse = _reflection.GeneratedProtocolMessageType('ActivityListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYLISTRESPONSE,
  '__module__' : 'activities_pb2'
  # @@protoc_insertion_point(class_scope:v1.ActivityListResponse)
  })
_sym_db.RegisterMessage(ActivityListResponse)

Activity = _reflection.GeneratedProtocolMessageType('Activity', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITY,
  '__module__' : 'activities_pb2'
  # @@protoc_insertion_point(class_scope:v1.Activity)
  })
_sym_db.RegisterMessage(Activity)

ActivityEntity = _reflection.GeneratedProtocolMessageType('ActivityEntity', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYENTITY,
  '__module__' : 'activities_pb2'
  # @@protoc_insertion_point(class_scope:v1.ActivityEntity)
  })
_sym_db.RegisterMessage(ActivityEntity)

ActivityActor = _reflection.GeneratedProtocolMessageType('ActivityActor', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYACTOR,
  '__module__' : 'activities_pb2'
  # @@protoc_insertion_point(class_scope:v1.ActivityActor)
  })
_sym_db.RegisterMessage(ActivityActor)

_ACTIVITIES = DESCRIPTOR.services_by_name['Activities']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\022ActivitiesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _ACTIVITYGETREQUEST.fields_by_name['id']._options = None
  _ACTIVITYGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITYGETREQUEST._options = None
  _ACTIVITYGETREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACTIVITYGETRESPONSE.fields_by_name['meta']._options = None
  _ACTIVITYGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITYGETRESPONSE.fields_by_name['activity']._options = None
  _ACTIVITYGETRESPONSE.fields_by_name['activity']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITYGETRESPONSE.fields_by_name['rate_limit']._options = None
  _ACTIVITYGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ACTIVITYGETRESPONSE._options = None
  _ACTIVITYGETRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider\372\370\263\007\005\250\363\263\007\001'
  _ACTIVITYLISTREQUEST.fields_by_name['filter']._options = None
  _ACTIVITYLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITYLISTREQUEST._options = None
  _ACTIVITYLISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACTIVITYLISTRESPONSE.fields_by_name['activities']._options = None
  _ACTIVITYLISTRESPONSE.fields_by_name['activities']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ACTIVITYLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ACTIVITYLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ACTIVITYLISTRESPONSE._options = None
  _ACTIVITYLISTRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACTIVITY.fields_by_name['id']._options = None
  _ACTIVITY.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITY.fields_by_name['verb']._options = None
  _ACTIVITY.fields_by_name['verb']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITY.fields_by_name['description']._options = None
  _ACTIVITY.fields_by_name['description']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITY.fields_by_name['completed_at']._options = None
  _ACTIVITY.fields_by_name['completed_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITY.fields_by_name['entities']._options = None
  _ACTIVITY.fields_by_name['entities']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITY.fields_by_name['ip_address']._options = None
  _ACTIVITY.fields_by_name['ip_address']._serialized_options = b'\362\370\263\007\036\260\363\263\007\001\312\363\263\007\024\302\364\263\007\017\n\002go\022\tIPAddress'
  _ACTIVITY.fields_by_name['actor']._options = None
  _ACTIVITY.fields_by_name['actor']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITY.fields_by_name['user_agent']._options = None
  _ACTIVITY.fields_by_name['user_agent']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITY._options = None
  _ACTIVITY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACTIVITYENTITY.fields_by_name['id']._options = None
  _ACTIVITYENTITY.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITYENTITY.fields_by_name['type']._options = None
  _ACTIVITYENTITY.fields_by_name['type']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITYENTITY.fields_by_name['name']._options = None
  _ACTIVITYENTITY.fields_by_name['name']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITYENTITY.fields_by_name['email']._options = None
  _ACTIVITYENTITY.fields_by_name['email']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITYENTITY.fields_by_name['external_id']._options = None
  _ACTIVITYENTITY.fields_by_name['external_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITYENTITY._options = None
  _ACTIVITYENTITY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACTIVITYACTOR.fields_by_name['id']._options = None
  _ACTIVITYACTOR.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITYACTOR.fields_by_name['email']._options = None
  _ACTIVITYACTOR.fields_by_name['email']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITYACTOR.fields_by_name['first_name']._options = None
  _ACTIVITYACTOR.fields_by_name['first_name']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITYACTOR.fields_by_name['last_name']._options = None
  _ACTIVITYACTOR.fields_by_name['last_name']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITYACTOR.fields_by_name['activity_external_id']._options = None
  _ACTIVITYACTOR.fields_by_name['activity_external_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVITYACTOR._options = None
  _ACTIVITYACTOR._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACTIVITIES._options = None
  _ACTIVITIES._serialized_options = b'\312\371\263\007\r\302\371\263\007\010Activity\312\371\263\007\010\322\371\263\007\003at-\312\371\263\007\005\330\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _ACTIVITIES.methods_by_name['Get']._options = None
  _ACTIVITIES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\030\252\363\263\007\023/v1/activities/{id}'
  _ACTIVITIES.methods_by_name['List']._options = None
  _ACTIVITIES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\023\252\363\263\007\016/v1/activities'
  _ACTIVITYGETREQUEST._serialized_start=84
  _ACTIVITYGETREQUEST._serialized_end=208
  _ACTIVITYGETRESPONSE._serialized_start=211
  _ACTIVITYGETRESPONSE._serialized_end=468
  _ACTIVITYLISTREQUEST._serialized_start=471
  _ACTIVITYLISTREQUEST._serialized_end=601
  _ACTIVITYLISTRESPONSE._serialized_start=604
  _ACTIVITYLISTRESPONSE._serialized_end=843
  _ACTIVITY._serialized_start=846
  _ACTIVITY._serialized_end=1238
  _ACTIVITYENTITY._serialized_start=1241
  _ACTIVITYENTITY._serialized_end=1445
  _ACTIVITYACTOR._serialized_start=1448
  _ACTIVITYACTOR._serialized_end=1671
  _ACTIVITIES._serialized_start=1674
  _ACTIVITIES._serialized_end=1967
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: remote_identities.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17remote_identities.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"\x7f\n\x1bRemoteIdentityCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x37\n\x0fremote_identity\x18\x02 \x01(\x0b\x32\x12.v1.RemoteIdentityB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf2\x01\n\x1cRemoteIdentityCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x37\n\x0fremote_identity\x18\x02 \x01(\x0b\x32\x12.v1.RemoteIdentityB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"X\n\x18RemoteIdentityGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xec\x01\n\x19RemoteIdentityGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x37\n\x0fremote_identity\x18\x02 \x01(\x0b\x32\x12.v1.RemoteIdentityB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x8b\x01\n\x1bRemoteIdentityUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12\x37\n\x0fremote_identity\x18\x03 \x01(\x0b\x32\x12.v1.RemoteIdentityB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf2\x01\n\x1cRemoteIdentityUpdateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x37\n\x0fremote_identity\x18\x02 \x01(\x0b\x32\x12.v1.RemoteIdentityB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"^\n\x1bRemoteIdentityDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb9\x01\n\x1cRemoteIdentityDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"^\n\x19RemoteIdentityListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd8\x01\n\x1aRemoteIdentityListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x39\n\x11remote_identities\x18\x02 \x03(\x0b\x32\x12.v1.RemoteIdentityB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\x91\x02\n\x0eRemoteIdentity\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12#\n\naccount_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x31\n\x18remote_identity_group_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x08username\x18\x04 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01:l\xfa\xf8\xb3\x07g\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07]\xa2\xf3\xb3\x07(tf_examples/remote_identity_resource.txt\xaa\xf3\xb3\x07+tf_examples/remote_identity_data_source.txt2\xa7\x05\n\x10RemoteIdentities\x12z\n\x06\x43reate\x12\x1f.v1.RemoteIdentityCreateRequest\x1a .v1.RemoteIdentityCreateResponse\"-\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1a\xaa\xf3\xb3\x07\x15/v1/remote-identities\x12u\n\x03Get\x12\x1c.v1.RemoteIdentityGetRequest\x1a\x1d.v1.RemoteIdentityGetResponse\"1\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1f\xaa\xf3\xb3\x07\x1a/v1/remote-identities/{id}\x12~\n\x06Update\x12\x1f.v1.RemoteIdentityUpdateRequest\x1a .v1.RemoteIdentityUpdateResponse\"1\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x1f\xaa\xf3\xb3\x07\x1a/v1/remote-identities/{id}\x12\x81\x01\n\x06\x44\x65lete\x12\x1f.v1.RemoteIdentityDeleteRequest\x1a .v1.RemoteIdentityDeleteResponse\"4\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x1f\xaa\xf3\xb3\x07\x1a/v1/remote-identities/{id}\x12s\n\x04List\x12\x1d.v1.RemoteIdentityListRequest\x1a\x1e.v1.RemoteIdentityListResponse\",\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1a\xaa\xf3\xb3\x07\x15/v1/remote-identities\x1a\'\x88\x02\x01\xca\xf9\xb3\x07\x13\xc2\xf9\xb3\x07\x0eRemoteIdentity\xca\xf9\xb3\x07\x07\xd2\xf9\xb3\x07\x02i-Bl\n\x19\x63om.strongdm.api.plumbingB\x18RemoteIdentitiesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_REMOTEIDENTITYCREATEREQUEST = DESCRIPTOR.message_types_by_name['RemoteIdentityCreateRequest']
_REMOTEIDENTITYCREATERESPONSE = DESCRIPTOR.message_types_by_name['RemoteIdentityCreateResponse']
_REMOTEIDENTITYGETREQUEST = DESCRIPTOR.message_types_by_name['RemoteIdentityGetRequest']
_REMOTEIDENTITYGETRESPONSE = DESCRIPTOR.message_types_by_name['RemoteIdentityGetResponse']
_REMOTEIDENTITYUPDATEREQUEST = DESCRIPTOR.message_types_by_name['RemoteIdentityUpdateRequest']
_REMOTEIDENTITYUPDATERESPONSE = DESCRIPTOR.message_types_by_name['RemoteIdentityUpdateResponse']
_REMOTEIDENTITYDELETEREQUEST = DESCRIPTOR.message_types_by_name['RemoteIdentityDeleteRequest']
_REMOTEIDENTITYDELETERESPONSE = DESCRIPTOR.message_types_by_name['RemoteIdentityDeleteResponse']
_REMOTEIDENTITYLISTREQUEST = DESCRIPTOR.message_types_by_name['RemoteIdentityListRequest']
_REMOTEIDENTITYLISTRESPONSE = DESCRIPTOR.message_types_by_name['RemoteIdentityListResponse']
_REMOTEIDENTITY = DESCRIPTOR.message_types_by_name['RemoteIdentity']
RemoteIdentityCreateRequest = _reflection.GeneratedProtocolMessageType('RemoteIdentityCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYCREATEREQUEST,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityCreateRequest)
  })
_sym_db.RegisterMessage(RemoteIdentityCreateRequest)

RemoteIdentityCreateResponse = _reflection.GeneratedProtocolMessageType('RemoteIdentityCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYCREATERESPONSE,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityCreateResponse)
  })
_sym_db.RegisterMessage(RemoteIdentityCreateResponse)

RemoteIdentityGetRequest = _reflection.GeneratedProtocolMessageType('RemoteIdentityGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYGETREQUEST,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityGetRequest)
  })
_sym_db.RegisterMessage(RemoteIdentityGetRequest)

RemoteIdentityGetResponse = _reflection.GeneratedProtocolMessageType('RemoteIdentityGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYGETRESPONSE,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityGetResponse)
  })
_sym_db.RegisterMessage(RemoteIdentityGetResponse)

RemoteIdentityUpdateRequest = _reflection.GeneratedProtocolMessageType('RemoteIdentityUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYUPDATEREQUEST,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityUpdateRequest)
  })
_sym_db.RegisterMessage(RemoteIdentityUpdateRequest)

RemoteIdentityUpdateResponse = _reflection.GeneratedProtocolMessageType('RemoteIdentityUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYUPDATERESPONSE,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityUpdateResponse)
  })
_sym_db.RegisterMessage(RemoteIdentityUpdateResponse)

RemoteIdentityDeleteRequest = _reflection.GeneratedProtocolMessageType('RemoteIdentityDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYDELETEREQUEST,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityDeleteRequest)
  })
_sym_db.RegisterMessage(RemoteIdentityDeleteRequest)

RemoteIdentityDeleteResponse = _reflection.GeneratedProtocolMessageType('RemoteIdentityDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYDELETERESPONSE,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityDeleteResponse)
  })
_sym_db.RegisterMessage(RemoteIdentityDeleteResponse)

RemoteIdentityListRequest = _reflection.GeneratedProtocolMessageType('RemoteIdentityListRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYLISTREQUEST,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityListRequest)
  })
_sym_db.RegisterMessage(RemoteIdentityListRequest)

RemoteIdentityListResponse = _reflection.GeneratedProtocolMessageType('RemoteIdentityListResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYLISTRESPONSE,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityListResponse)
  })
_sym_db.RegisterMessage(RemoteIdentityListResponse)

RemoteIdentity = _reflection.GeneratedProtocolMessageType('RemoteIdentity', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITY,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentity)
  })
_sym_db.RegisterMessage(RemoteIdentity)

_REMOTEIDENTITIES = DESCRIPTOR.services_by_name['RemoteIdentities']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\030RemoteIdentitiesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _REMOTEIDENTITYCREATEREQUEST.fields_by_name['remote_identity']._options = None
  _REMOTEIDENTITYCREATEREQUEST.fields_by_name['remote_identity']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYCREATERESPONSE.fields_by_name['meta']._options = None
  _REMOTEIDENTITYCREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYCREATERESPONSE.fields_by_name['remote_identity']._options = None
  _REMOTEIDENTITYCREATERESPONSE.fields_by_name['remote_identity']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _REMOTEIDENTITYCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _REMOTEIDENTITYCREATERESPONSE._options = None
  _REMOTEIDENTITYCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _REMOTEIDENTITYGETREQUEST.fields_by_name['id']._options = None
  _REMOTEIDENTITYGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYGETRESPONSE.fields_by_name['meta']._options = None
  _REMOTEIDENTITYGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYGETRESPONSE.fields_by_name['remote_identity']._options = None
  _REMOTEIDENTITYGETRESPONSE.fields_by_name['remote_identity']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYGETRESPONSE.fields_by_name['rate_limit']._options = None
  _REMOTEIDENTITYGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _REMOTEIDENTITYGETRESPONSE._options = None
  _REMOTEIDENTITYGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _REMOTEIDENTITYUPDATEREQUEST.fields_by_name['remote_identity']._options = None
  _REMOTEIDENTITYUPDATEREQUEST.fields_by_name['remote_identity']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYUPDATERESPONSE.fields_by_name['meta']._options = None
  _REMOTEIDENTITYUPDATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYUPDATERESPONSE.fields_by_name['remote_identity']._options = None
  _REMOTEIDENTITYUPDATERESPONSE.fields_by_name['remote_identity']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _REMOTEIDENTITYUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _REMOTEIDENTITYUPDATERESPONSE._options = None
  _REMOTEIDENTITYUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _REMOTEIDENTITYDELETEREQUEST.fields_by_name['id']._options = None
  _REMOTEIDENTITYDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYDELETERESPONSE.fields_by_name['meta']._options = None
  _REMOTEIDENTITYDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _REMOTEIDENTITYDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _REMOTEIDENTITYDELETERESPONSE._options = None
  _REMOTEIDENTITYDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _REMOTEIDENTITYLISTREQUEST.fields_by_name['filter']._options = None
  _REMOTEIDENTITYLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYLISTRESPONSE.fields_by_name['remote_identities']._options = None
  _REMOTEIDENTITYLISTRESPONSE.fields_by_name['remote_identities']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _REMOTEIDENTITYLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _REMOTEIDENTITYLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _REMOTEIDENTITY.fields_by_name['id']._options = None
  _REMOTEIDENTITY.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITY.fields_by_name['account_id']._options = None
  _REMOTEIDENTITY.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _REMOTEIDENTITY.fields_by_name['remote_identity_group_id']._options = None
  _REMOTEIDENTITY.fields_by_name['remote_identity_group_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _REMOTEIDENTITY.fields_by_name['username']._options = None
  _REMOTEIDENTITY.fields_by_name['username']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _REMOTEIDENTITY._options = None
  _REMOTEIDENTITY._serialized_options = b'\372\370\263\007g\250\363\263\007\001\302\363\263\007]\242\363\263\007(tf_examples/remote_identity_resource.txt\252\363\263\007+tf_examples/remote_identity_data_source.txt'
  _REMOTEIDENTITIES._options = None
  _REMOTEIDENTITIES._serialized_options = b'\210\002\001\312\371\263\007\023\302\371\263\007\016RemoteIdentity\312\371\263\007\007\322\371\263\007\002i-'
  _REMOTEIDENTITIES.methods_by_name['Create']._options = None
  _REMOTEIDENTITIES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\032\252\363\263\007\025/v1/remote-identities'
  _REMOTEIDENTITIES.methods_by_name['Get']._options = None
  _REMOTEIDENTITIES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\037\252\363\263\007\032/v1/remote-identities/{id}'
  _REMOTEIDENTITIES.methods_by_name['Update']._options = None
  _REMOTEIDENTITIES.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\037\252\363\263\007\032/v1/remote-identities/{id}'
  _REMOTEIDENTITIES.methods_by_name['Delete']._options = None
  _REMOTEIDENTITIES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\037\252\363\263\007\032/v1/remote-identities/{id}'
  _REMOTEIDENTITIES.methods_by_name['List']._options = None
  _REMOTEIDENTITIES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\032\252\363\263\007\025/v1/remote-identities'
  _REMOTEIDENTITYCREATEREQUEST._serialized_start=58
  _REMOTEIDENTITYCREATEREQUEST._serialized_end=185
  _REMOTEIDENTITYCREATERESPONSE._serialized_start=188
  _REMOTEIDENTITYCREATERESPONSE._serialized_end=430
  _REMOTEIDENTITYGETREQUEST._serialized_start=432
  _REMOTEIDENTITYGETREQUEST._serialized_end=520
  _REMOTEIDENTITYGETRESPONSE._serialized_start=523
  _REMOTEIDENTITYGETRESPONSE._serialized_end=759
  _REMOTEIDENTITYUPDATEREQUEST._serialized_start=762
  _REMOTEIDENTITYUPDATEREQUEST._serialized_end=901
  _REMOTEIDENTITYUPDATERESPONSE._serialized_start=904
  _REMOTEIDENTITYUPDATERESPONSE._serialized_end=1146
  _REMOTEIDENTITYDELETEREQUEST._serialized_start=1148
  _REMOTEIDENTITYDELETEREQUEST._serialized_end=1242
  _REMOTEIDENTITYDELETERESPONSE._serialized_start=1245
  _REMOTEIDENTITYDELETERESPONSE._serialized_end=1430
  _REMOTEIDENTITYLISTREQUEST._serialized_start=1432
  _REMOTEIDENTITYLISTREQUEST._serialized_end=1526
  _REMOTEIDENTITYLISTRESPONSE._serialized_start=1529
  _REMOTEIDENTITYLISTRESPONSE._serialized_end=1745
  _REMOTEIDENTITY._serialized_start=1748
  _REMOTEIDENTITY._serialized_end=2021
  _REMOTEIDENTITIES._serialized_start=2024
  _REMOTEIDENTITIES._serialized_end=2703
# @@protoc_insertion_point(module_scope)
